@@ -53,7 +53,7 @@ def buildDriver(proxy, **kw):
 
 class IOSSpeechDriver(BaseDriver):
 	def __init__(self, proxy, **kw):
-		sper().__init__(proxy)
+		super().__init__(proxy)
 		self._tts = AVSpeechSynthesizer.alloc().init()
 		self._tts.delegate = self
 		self.rate = 200
@@ -77,9 +77,20 @@ class IOSSpeechDriver(BaseDriver):
 					return v.id
 		raise Exception(f'{lang} is not supported language')
 			
+	def _toVoice(voice):
+		id = voice.identifier
+		name = voice.name
+		v = Voice(id)
+		v.name = voice.name
+		v.gender = voice.gender
+		v.languages = voice.language
+		return v
+
 	def get_voices(self):
 		voices = AVSpeechSynthesisVoice.speechVoices()
-		x = [ self._toVoice(v) for v in voices ]
+		x = [ self._toVoice(v) for v in \
+					[voices.objectAtIndex_(i) \
+							for i in range(voices.count()) ] ]
 		self.voices = x
 		return x
 		
@@ -90,10 +101,10 @@ class IOSSpeechDriver(BaseDriver):
 		self._tts.delegate = None
 		del self._tts
 		self._tts = None
-
+		
 	def pre_command(self, sentence):
 		return sentence.sentence_id, sentence
-
+		
 	def command(self, pos, sentence):
 		self.speak_sentence(sentence)
 
